.. _jacapo:

========================================
Jacapo - ASE python interface for Dacapo
========================================

.. note::

   ASE-3.20.0 removes support for Dacapo (through Jacapo) due to lack
   of maintenance.  Presumably Dacapo has no active users.  If a
   Dacapo calculator is nevertheless in great demand,
   the source code can be found in commit
   f179b989a94273774e62d6972f587a5e1396d73a.
